@@ -4,10 +4,22 @@
 # @alias toEMF
 # @alias toEPS
 # @alias toPDF
+# %% @alias toCairoPNG
 # @alias toPNG
 # @alias toSVG
 # @alias toTIFF
 # @alias toWMF
+# @alias toFavicon
+# @alias asDataURI
+#
+# % Interactive/screen devices
+# @alias toDefault
+# @alias toQuartz
+# @alias toWindows
+# @alias toX11
+# @alias toCairoWin
+# @alias toCairoX11
+# %% @alias toJavaGD
 #
 # @title "Methods for creating image files of a specific format"
 #
@@ -23,6 +35,21 @@
 #   toSVG(name, ..., field=getOption("devEval/args/field", "fullname"))
 #   toTIFF(name, ..., field=getOption("devEval/args/field", "fullname"))
 #   toWMF(name, ..., ext="wmf", field=getOption("devEval/args/field", "fullname"))
+#   %% toCairoPNG(name, ..., field=getOption("devEval/args/field", "fullname"))
+#
+#   toFavicon(..., name="favicon", type="png", width=32L, height=width,
+#                  par=list(mar=c(0,0,0,0), bg="transparent"))
+#
+#   % Interactive/screen devices
+#   toDefault(name, ...)
+#   toQuartz(name, ...)
+#   toX11(name, ...)
+#   toWindows(name, ...)
+#
+#   % Interactive/screen devices from other packages
+#   toCairoWin(name, ...)
+#   toCairoX11(name, ...)
+#   %% toJavaGD(name, ...)
 # }
 #
 # \arguments{
@@ -31,6 +58,7 @@
 #      \code{tags} and \code{aspectRatio}.}
 #   \item{ext}{A @character string specifying the filename extension.}
 #   \item{field}{Passed to @see "devEval".}
+#   \item{width, height, type, par}{Passed to @see "devEval".}
 # }
 #
 # \value{
@@ -82,9 +110,70 @@ toTIFF <- function(name, ..., field=getOption("devEval/args/field", "fullname"))
   devEval(type="tiff", name=name, ..., field=field);
 }
 
+## toCairoPNG <- function(name, ..., field=getOption("devEval/args/field", "fullname")) {
+##   devEval(type="CairoPNG", name=name, ..., field=field);
+## }
+
+
+toFavicon <- function(..., name="favicon", type="png", width=32L, height=width, par=list(mar=c(0,0,0,0), bg="transparent")) {
+  # png() will generate a warning that "width=.. , height=.., are unlikely
+  # values in pixels" if width < 20.
+  suppressWarnings({
+    devEval(type=type, name=name, width=width, height=height, par=par, ...);
+  })
+}
+
+asDataURI <- function(..., mime=NULL) {
+  img <- DevEvalFileProduct(...);
+  if (is.null(mime)) {
+    mime <- getMimeType(img);
+  }
+  getDataURI(img, mime=mime);
+}
+
+
+toDefault <- function(name, ...) {
+  devEval(type=getOption("device"), name=name, ...);
+}
+
+toQuartz <- function(name, ...) {
+  devEval(type="quartz", name=name, ...);
+}
+
+toWindows <- function(name, ...) {
+  devEval(type="windows", name=name, ...);
+}
+
+toX11 <- function(name, ...) {
+  devEval(type="X11", name=name, ...);
+}
+
+toCairoWin <- function(name, ...) {
+  devEval(type="CairoWin", name=name, ...);
+}
+
+toCairoX11 <- function(name, ...) {
+  devEval(type="CairoX11", name=name, ...);
+}
+
+## toJavaGD <- function(name, ...) {
+##   devEval(type="JavaGD", name=name, ...);
+## }
+
+
+
+
 
 ##############################################################################
 # HISTORY:
+# 2014-04-28
+# o Waiting with toCairoPNG() and toJavaGD().
+# o Added toDefault(), toX11(), toWindows(), and toQuartz().
+#   Also added toCairoWin() and toCairoX11() for the 'Cairo' package.
+# 2014-01-11
+# o Added asDataURI().
+# 2014-01-10
+# o Added toFavicon().
 # 2013-07-24
 # o Added toEMF()/toWMF().
 # 2013-02-23
